public inbox for passt-dev@passt.top
 help / color / mirror / code / Atom feed
From: David Gibson <david@gibson.dropbear.id.au>
To: passt-dev@passt.top, Stefano Brivio <sbrivio@redhat.com>
Cc: David Gibson <david@gibson.dropbear.id.au>
Subject: [PATCH v2 01/14] nstool: Rename nsholder to nstool
Date: Thu,  6 Apr 2023 13:28:06 +1000	[thread overview]
Message-ID: <20230406032819.707441-2-david@gibson.dropbear.id.au> (raw)
In-Reply-To: <20230406032819.707441-1-david@gibson.dropbear.id.au>

In preparation for extending what it does.

Signed-off-by: David Gibson <david@gibson.dropbear.id.au>
---
 test/.gitignore               |  2 +-
 test/Makefile                 |  4 ++--
 test/lib/setup                | 30 +++++++++++++++---------------
 test/{nsholder.c => nstool.c} | 22 +++++++++++-----------
 4 files changed, 29 insertions(+), 29 deletions(-)
 rename test/{nsholder.c => nstool.c} (82%)

diff --git a/test/.gitignore b/test/.gitignore
index fbee491..4837402 100644
--- a/test/.gitignore
+++ b/test/.gitignore
@@ -6,6 +6,6 @@ QEMU_EFI.fd
 *.raw
 *.raw.xz
 *.bin
-nsholder
+nstool
 guest-key
 guest-key.pub
diff --git a/test/Makefile b/test/Makefile
index 1341677..50d283e 100644
--- a/test/Makefile
+++ b/test/Makefile
@@ -58,7 +58,7 @@ TESTDATA_ASSETS = small.bin big.bin medium.bin
 LOCAL_ASSETS = mbuto.img mbuto.mem.img QEMU_EFI.fd \
 	$(DEBIAN_IMGS:%=prepared-%) $(FEDORA_IMGS:%=prepared-%) \
 	$(UBUNTU_NEW_IMGS:%=prepared-%) \
-	nsholder guest-key guest-key.pub \
+	nstool guest-key guest-key.pub \
 	$(TESTDATA_ASSETS)
 
 ASSETS = $(DOWNLOAD_ASSETS) $(LOCAL_ASSETS)
@@ -79,7 +79,7 @@ mbuto.img: passt.mbuto mbuto guest-key.pub $(TESTDATA_ASSETS)
 mbuto.mem.img: passt.mem.mbuto mbuto ../passt.avx2
 	./mbuto/mbuto -p ./$< -c lz4 -f $@
 
-nsholder: nsholder.c
+nstool: nstool.c
 	$(CC) $(CFLAGS) -o $@ $^
 
 QEMU_EFI.fd:
diff --git a/test/lib/setup b/test/lib/setup
index 5f8ce26..3bd434b 100755
--- a/test/lib/setup
+++ b/test/lib/setup
@@ -17,7 +17,7 @@ INITRAMFS="${BASEPATH}/mbuto.img"
 VCPUS="$( [ $(nproc) -ge 8 ] && echo 6 || echo $(( $(nproc) / 2 + 1 )) )"
 __mem_kib="$(sed -n 's/MemTotal:[ ]*\([0-9]*\) kB/\1/p' /proc/meminfo)"
 VMEM="$((${__mem_kib} / 1024 / 4))"
-NSHOLDER="${BASEPATH}/nsholder"
+NSTOOL="${BASEPATH}/nstool"
 
 # setup_build() - Set up pane layout for build tests
 setup_build() {
@@ -77,8 +77,8 @@ setup_pasta() {
 
 	layout_pasta
 
-	context_run_bg unshare "unshare -rUnpf ${NSHOLDER} ${STATESETUP}/ns.hold hold"
-	__target_pid=$(${NSHOLDER} ${STATESETUP}/ns.hold pid)
+	context_run_bg unshare "unshare -rUnpf ${NSTOOL} ${STATESETUP}/ns.hold hold"
+	__target_pid=$(${NSTOOL} ${STATESETUP}/ns.hold pid)
 
 	context_setup_nsenter ns -U -n -p --preserve-credentials -t ${__target_pid}
 
@@ -126,9 +126,9 @@ setup_passt_in_ns() {
 	[ ${DEBUG} -eq 1 ] && __opts="${__opts} -d"
 	[ ${TRACE} -eq 1 ] && __opts="${__opts} --trace"
 
-	context_run_bg pasta "./pasta ${__opts} -t 10001,10002,10011,10012 -T 10003,10013 -u 10001,10002,10011,10012 -U 10003,10013 -P ${STATESETUP}/pasta.pid --config-net ${NSHOLDER} ${STATESETUP}/ns.hold hold"
+	context_run_bg pasta "./pasta ${__opts} -t 10001,10002,10011,10012 -T 10003,10013 -u 10001,10002,10011,10012 -U 10003,10013 -P ${STATESETUP}/pasta.pid --config-net ${NSTOOL} ${STATESETUP}/ns.hold hold"
 	wait_for [ -f "${STATESETUP}/pasta.pid" ]
-	__ns_pid=$(${NSHOLDER} ${STATESETUP}/ns.hold pid)
+	__ns_pid=$(${NSTOOL} ${STATESETUP}/ns.hold pid)
 
 	context_setup_nsenter qemu "-t ${__ns_pid} -U -n -p --preserve-credentials"
 	context_setup_nsenter ns "-t ${__ns_pid} -U -n -p --preserve-credentials"
@@ -189,16 +189,16 @@ setup_two_guests() {
 	[ ${PCAP} -eq 1 ] && __opts="${__opts} -p ${LOGDIR}/pasta_1.pcap"
 	[ ${DEBUG} -eq 1 ] && __opts="${__opts} -d"
 	[ ${TRACE} -eq 1 ] && __opts="${__opts} --trace"
-	context_run_bg pasta_1 "./pasta ${__opts} --trace -l /tmp/pasta1.log -P ${STATESETUP}/pasta_1.pid -t 10001,10002 -T 10003,10004 -u 10001,10002 -U 10003,10004 --config-net ${NSHOLDER} ${STATESETUP}/ns1.hold hold"
-	__ns1_pid=$(${NSHOLDER} ${STATESETUP}/ns1.hold pid)
+	context_run_bg pasta_1 "./pasta ${__opts} --trace -l /tmp/pasta1.log -P ${STATESETUP}/pasta_1.pid -t 10001,10002 -T 10003,10004 -u 10001,10002 -U 10003,10004 --config-net ${NSTOOL} ${STATESETUP}/ns1.hold hold"
+	__ns1_pid=$(${NSTOOL} ${STATESETUP}/ns1.hold pid)
 	context_setup_nsenter passt_1 -U -n -p --preserve-credentials -t ${__ns1_pid}
 
 	__opts=
 	[ ${PCAP} -eq 1 ] && __opts="${__opts} -p ${LOGDIR}/pasta_2.pcap"
 	[ ${DEBUG} -eq 1 ] && __opts="${__opts} -d"
 	[ ${TRACE} -eq 1 ] && __opts="${__opts} --trace"
-	context_run_bg pasta_2 "./pasta ${__opts} --trace -l /tmp/pasta2.log -P ${STATESETUP}/pasta_2.pid -t 10004,10005 -T 10003,10001 -u 10004,10005 -U 10003,10001 --config-net ${NSHOLDER} ${STATESETUP}/ns2.hold hold"
-	__ns2_pid=$(${NSHOLDER} ${STATESETUP}/ns2.hold pid)
+	context_run_bg pasta_2 "./pasta ${__opts} --trace -l /tmp/pasta2.log -P ${STATESETUP}/pasta_2.pid -t 10004,10005 -T 10003,10001 -u 10004,10005 -U 10003,10001 --config-net ${NSTOOL} ${STATESETUP}/ns2.hold hold"
+	__ns2_pid=$(${NSTOOL} ${STATESETUP}/ns2.hold pid)
 	context_setup_nsenter passt_2 -U -n -p --preserve-credentials -t ${__ns2_pid}
 
 	context_setup_nsenter qemu_1 -U -n -p --preserve-credentials -t ${__ns1_pid}
@@ -284,7 +284,7 @@ teardown_passt() {
 
 # teardown_pasta() - Exit namespace, kill pasta process
 teardown_pasta() {
-	${NSHOLDER} "${STATESETUP}/ns.hold" stop
+	${NSTOOL} "${STATESETUP}/ns.hold" stop
 	context_wait unshare
 
 	teardown_context_watch ${PANE_HOST} host
@@ -297,7 +297,7 @@ teardown_passt_in_ns() {
 	context_run ns kill $(cat "${STATESETUP}/qemu.pid")
 	context_wait qemu
 
-	${NSHOLDER} "${STATESETUP}/ns.hold" stop
+	${NSTOOL} "${STATESETUP}/ns.hold" stop
 	context_wait pasta
 
 	rm "${STATESETUP}/passt.pid" "${STATESETUP}/pasta.pid"
@@ -310,8 +310,8 @@ teardown_passt_in_ns() {
 
 # teardown_two_guests() - Exit namespaces, kill qemu processes, passt and pasta
 teardown_two_guests() {
-	__ns1_pid=$(${NSHOLDER} "${STATESETUP}/ns1.hold" pid)
-	__ns2_pid=$(${NSHOLDER} "${STATESETUP}/ns2.hold" pid)
+	__ns1_pid=$(${NSTOOL} "${STATESETUP}/ns1.hold" pid)
+	__ns2_pid=$(${NSTOOL} "${STATESETUP}/ns2.hold" pid)
 	nsenter -U -p --preserve-credentials -t ${__ns1_pid} kill $(cat "${STATESETUP}/qemu_1.pid")
 	nsenter -U -p --preserve-credentials -t ${__ns2_pid} kill $(cat "${STATESETUP}/qemu_2.pid")
 	context_wait qemu_1
@@ -321,8 +321,8 @@ teardown_two_guests() {
 	nsenter -U -p --preserve-credentials -t ${__ns2_pid} kill $(cat "${STATESETUP}/passt_2.pid")
 	context_wait passt_1
 	context_wait passt_2
-	${NSHOLDER} "${STATESETUP}/ns1.hold" stop
-	${NSHOLDER} "${STATESETUP}/ns2.hold" stop
+	${NSTOOL} "${STATESETUP}/ns1.hold" stop
+	${NSTOOL} "${STATESETUP}/ns2.hold" stop
 	context_wait pasta_1
 	context_wait pasta_2
 
diff --git a/test/nsholder.c b/test/nstool.c
similarity index 82%
rename from test/nsholder.c
rename to test/nstool.c
index 010a051..958ece7 100644
--- a/test/nsholder.c
+++ b/test/nstool.c
@@ -1,23 +1,23 @@
 // SPDX-License-Identifier: AGPL-3.0-or-later
 
 /* nsholder - maintain a namespace to be entered by other processes
  *
  * Copyright Red Hat
  * Author: David Gibson <david@gibson.dropbear.id.au>
  *
  * Can run in 3 modes:
  *
- *   nsholder <path> hold
+ *   nstool <path> hold
  *      Designed to be run inside a namespace, opens a Unix domain
  *      control socket at <path> and waits until instructed to stop
  *      with "nsholder <path> stop"
  *   nsholder <path> pid
  *      Prints the PID of the nsholder hold process with control
  *      socket <path>.  This is given in the PID namespace where
  *      nsholder pid is executed, not the one where nsholder hold is
  *      running
  *   nsholder <path> stop
  *      Instruct the nsholder hold with control socket at <path> to exit.
  */
 
 #define _GNU_SOURCE
@@ -38,7 +38,7 @@
 
 static void usage(void)
 {
-	die("Usage: holder <socket path> hold|pid\n");
+	die("Usage: nstool <socket path> hold|pid\n");
 }
 
 static void hold(int fd, const struct sockaddr_un *addr)
@@ -53,7 +53,7 @@ static void hold(int fd, const struct sockaddr_un *addr)
 	if (rc < 0)
 		die("listen(): %s\n", strerror(errno));
 
-	printf("nsholder: local PID=%d  local UID=%u  local GID=%u\n",
+	printf("nstool: local PID=%d  local UID=%u  local GID=%u\n",
 	       getpid(), getuid(), getgid());
 	do {
 		int afd = accept(fd, NULL, NULL);
@@ -103,7 +103,7 @@ static void stop(int fd, const struct sockaddr_un *addr)
 
 	rc = write(fd, &buf, sizeof(buf));
 	if (rc < 0)
-		die("write(): %s\n",  strerror(errno));
+		die("write(): %s\n", strerror(errno));
 
 	close(fd);
 }
@@ -1,23 +1,23 @@
 // SPDX-License-Identifier: AGPL-3.0-or-later
 
-/* nsholder - maintain a namespace to be entered by other processes
+/* nstool - maintain a namespace to be entered by other processes
  *
  * Copyright Red Hat
@@ -1,23 +1,23 @@
  *      Designed to be run inside a namespace, opens a Unix domain
  *      control socket at <path> and waits until instructed to stop
- *      with "nsholder <path> stop"
- *   nsholder <path> pid
- *      Prints the PID of the nsholder hold process with control
+ *      with "nstool <path> stop"
+ *   nstool <path> pid
+ *      Prints the PID of the nstool hold process with control
  *      socket <path>.  This is given in the PID namespace where
@@ -1,23 +1,23 @@
  *      socket <path>.  This is given in the PID namespace where
- *      nsholder pid is executed, not the one where nsholder hold is
+ *      nstool pid is executed, not the one where nstool hold is
  *      running
@@ -1,23 +1,23 @@
  *      running
- *   nsholder <path> stop
- *      Instruct the nsholder hold with control socket at <path> to exit.
+ *   nstool <path> stop
+ *      Instruct the nstool hold with control socket at <path> to exit.
  */
 
-- 
@@ -1,23 +1,23 @@
 // SPDX-License-Identifier: AGPL-3.0-or-later
 
-/* nsholder - maintain a namespace to be entered by other processes
+/* nstool - maintain a namespace to be entered by other processes
  *
  * Copyright Red Hat
  * Author: David Gibson <david@gibson.dropbear.id.au>
  *
  * Can run in 3 modes:
  *
- *   nsholder <path> hold
+ *   nstool <path> hold
  *      Designed to be run inside a namespace, opens a Unix domain
  *      control socket at <path> and waits until instructed to stop
- *      with "nsholder <path> stop"
- *   nsholder <path> pid
- *      Prints the PID of the nsholder hold process with control
+ *      with "nstool <path> stop"
+ *   nstool <path> pid
+ *      Prints the PID of the nstool hold process with control
  *      socket <path>.  This is given in the PID namespace where
- *      nsholder pid is executed, not the one where nsholder hold is
+ *      nstool pid is executed, not the one where nstool hold is
  *      running
- *   nsholder <path> stop
- *      Instruct the nsholder hold with control socket at <path> to exit.
+ *   nstool <path> stop
+ *      Instruct the nstool hold with control socket at <path> to exit.
  */
 
 #define _GNU_SOURCE
@@ -38,7 +38,7 @@
 
 static void usage(void)
 {
-	die("Usage: holder <socket path> hold|pid\n");
+	die("Usage: nstool <socket path> hold|pid\n");
 }
 
 static void hold(int fd, const struct sockaddr_un *addr)
@@ -53,7 +53,7 @@ static void hold(int fd, const struct sockaddr_un *addr)
 	if (rc < 0)
 		die("listen(): %s\n", strerror(errno));
 
-	printf("nsholder: local PID=%d  local UID=%u  local GID=%u\n",
+	printf("nstool: local PID=%d  local UID=%u  local GID=%u\n",
 	       getpid(), getuid(), getgid());
 	do {
 		int afd = accept(fd, NULL, NULL);
@@ -103,7 +103,7 @@ static void stop(int fd, const struct sockaddr_un *addr)
 
 	rc = write(fd, &buf, sizeof(buf));
 	if (rc < 0)
-		die("write(): %s\n",  strerror(errno));
+		die("write(): %s\n", strerror(errno));
 
 	close(fd);
 }
-- 
2.39.2


  reply	other threads:[~2023-04-06  3:28 UTC|newest]

Thread overview: 16+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-04-06  3:28 [PATCH v2 00/14] Improved tool for testing across multiple namespaces David Gibson
2023-04-06  3:28 ` David Gibson [this message]
2023-04-06  3:28 ` [PATCH v2 02/14] nstool: Reverse parameters to nstool David Gibson
2023-04-06  3:28 ` [PATCH v2 03/14] nstool: Move description of its operation modes from comment to usage David Gibson
2023-04-06  3:28 ` [PATCH v2 04/14] nstool: Split some command line parsing and socket setup to subcommands David Gibson
2023-04-06  3:28 ` [PATCH v2 05/14] nstool: Replace "pid" subcommand with "info" subcommand David Gibson
2023-04-06  3:28 ` [PATCH v2 06/14] nstool: Detect what namespaces target is in David Gibson
2023-04-06  3:28 ` [PATCH v2 07/14] nstool: Add magic number to advertized information David Gibson
2023-04-06  3:28 ` [PATCH v2 08/14] nstool: Helpers to iterate through namespace types David Gibson
2023-04-06  3:28 ` [PATCH v2 09/14] nstool: Add nstool exec command to execute commands in an nstool namespace David Gibson
2023-04-06  3:28 ` [PATCH v2 10/14] nstool: Add --keep-caps option to nstool exec David Gibson
2023-04-06  3:28 ` [PATCH v2 11/14] test: Initialise ${TRACE} properly David Gibson
2023-04-06  3:28 ` [PATCH v2 12/14] test: Use "nstool exec" to slightly simplify tests David Gibson
2023-04-06  3:28 ` [PATCH v2 13/14] nstool: Advertise the holder's cwd (in its mountns) across the socket David Gibson
2023-04-06  3:28 ` [PATCH v2 14/14] nstool: Enter holder's cwd when changing mount ns with nstool exec David Gibson
2023-04-07 23:12 ` [PATCH v2 00/14] Improved tool for testing across multiple namespaces Stefano Brivio

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230406032819.707441-2-david@gibson.dropbear.id.au \
    --to=david@gibson.dropbear.id.au \
    --cc=passt-dev@passt.top \
    --cc=sbrivio@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://passt.top/passt

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for IMAP folder(s).